@@ -16,6 +16,7 @@ from wnm.common import (
     DEFAULT_CRISIS_BYTES,
     DISABLED,
     DONATE,
+    FAUCET,
     MIGRATING,
     QUEEN,
     REMOVING,
@@ -36,31 +37,150 @@ logging.getLogger("sqlalchemy.engine.Engine").disabled = True
 
 PLATFORM = platform.system()  # 'Linux', 'Darwin', 'Windows'
 
-# Determine if running as root on Linux
+# Determine if running as root on Linux (kept for backwards compatibility)
 IS_ROOT = PLATFORM == "Linux" and os.geteuid() == 0
 
-# Platform-specific base directories
-if PLATFORM == "Darwin":
-    # macOS: Use standard macOS application directories
-    BASE_DIR = os.path.expanduser("~/Library/Application Support/autonomi")
-    NODE_STORAGE = os.path.expanduser("~/Library/Application Support/autonomi/node")
-    LOG_DIR = os.path.expanduser("~/Library/Logs/autonomi")
-    BOOTSTRAP_CACHE_DIR = os.path.expanduser("~/Library/Caches/autonomi/bootstrap-cache")
-elif PLATFORM == "Linux":
+
+def _detect_process_manager_mode():
+    """
+    Detect the process manager mode early to determine path selection.
+
+    Checks (in priority order):
+    1. --process_manager command line argument
+    2. PROCESS_MANAGER environment variable
+    3. Existing database in either sudo or user paths
+    4. Fallback to IS_ROOT-based detection for backwards compatibility
+
+    Returns:
+        str: "sudo" or "user" indicating the mode
+    """
+    # Check command line args first (quick parse without configargparse)
+    for i, arg in enumerate(sys.argv):
+        if arg == "--process_manager" and i + 1 < len(sys.argv):
+            pm = sys.argv[i + 1]
+            if "+sudo" in pm:
+                return "sudo"
+            elif "+user" in pm:
+                return "user"
+
+    # Check environment variable
+    pm_env = os.getenv("PROCESS_MANAGER")
+    if pm_env:
+        if "+sudo" in pm_env:
+            return "sudo"
+        elif "+user" in pm_env:
+            return "user"
+
+    # Check if .env file exists and load it
+    env_file = os.path.expanduser("~/.local/share/wnm/.env")
+    if os.path.exists(env_file):
+        load_dotenv(env_file)
+        pm_env = os.getenv("PROCESS_MANAGER")
+        if pm_env:
+            if "+sudo" in pm_env:
+                return "sudo"
+            elif "+user" in pm_env:
+                return "user"
+
+    # Check for existing databases to auto-detect mode
+    # Try both potential locations and read process_manager from machine table
+    import sqlite3
+
+    db_locations = []
+
+    # Check for --dbpath command line argument first
+    for i, arg in enumerate(sys.argv):
+        if arg == "--dbpath" and i + 1 < len(sys.argv):
+            dbpath_arg = sys.argv[i + 1]
+            # Remove sqlite:/// prefix if present
+            if dbpath_arg.startswith("sqlite:///"):
+                dbpath_arg = dbpath_arg[10:]
+            db_locations.append(dbpath_arg)
+            break
+
+    # Check for DBPATH environment variable
+    dbpath_env = os.getenv("DBPATH")
+    if dbpath_env:
+        # Remove sqlite:/// prefix if present
+        if dbpath_env.startswith("sqlite:///"):
+            dbpath_env = dbpath_env[10:]
+        # Expand variables like $HOME
+        dbpath_env = os.path.expandvars(dbpath_env)
+        db_locations.append(dbpath_env)
+
+    # Add platform-specific default locations
+    if PLATFORM == "Linux":
+        db_locations.extend([
+            "/var/antctl/colony.db",  # sudo mode
+            os.path.expanduser("~/.local/share/autonomi/colony.db"),  # user mode
+        ])
+    elif PLATFORM == "Darwin":
+        db_locations.extend([
+            "/Library/Application Support/autonomi/colony.db",  # sudo mode
+            os.path.expanduser("~/Library/Application Support/autonomi/colony.db"),  # user mode
+        ])
+
+    for db_path in db_locations:
+        if os.path.exists(db_path):
+            try:
+                conn = sqlite3.connect(db_path)
+                cursor = conn.cursor()
+                cursor.execute("SELECT process_manager FROM machine WHERE id = 1")
+                row = cursor.fetchone()
+                conn.close()
+
+                if row and row[0]:
+                    pm = row[0]
+                    if "+sudo" in pm:
+                        return "sudo"
+                    elif "+user" in pm:
+                        return "user"
+            except (sqlite3.Error, IndexError):
+                # Database exists but can't read it - try next location
+                continue
+
+    # Fallback to IS_ROOT for backwards compatibility
+    # If running as actual root, assume sudo mode (system-wide paths)
     if IS_ROOT:
-        # Linux root: Use legacy /var/antctl paths for backwards compatibility
+        return "sudo"
+
+    # Default to user mode
+    return "user"
+
+
+# Detect the process manager mode early
+_PM_MODE = _detect_process_manager_mode()
+
+# Platform-specific base directories based on process manager mode
+if PLATFORM == "Darwin":
+    # macOS paths
+    if _PM_MODE == "sudo":
+        # System-wide paths for launchd+sudo
+        BASE_DIR = "/Library/Application Support/autonomi"
+        NODE_STORAGE = "/Library/Application Support/autonomi/node"
+        LOG_DIR = "/Library/Logs/autonomi"
+        BOOTSTRAP_CACHE_DIR = "/Library/Caches/autonomi/bootstrap-cache"
+    else:
+        # User-level paths for launchd+user (default)
+        BASE_DIR = os.path.expanduser("~/Library/Application Support/autonomi")
+        NODE_STORAGE = os.path.expanduser("~/Library/Application Support/autonomi/node")
+        LOG_DIR = os.path.expanduser("~/Library/Logs/autonomi")
+        BOOTSTRAP_CACHE_DIR = os.path.expanduser("~/Library/Caches/autonomi/bootstrap-cache")
+elif PLATFORM == "Linux":
+    if _PM_MODE == "sudo":
+        # System-wide paths for systemd+sudo or setsid+sudo
         BASE_DIR = "/var/antctl"
         NODE_STORAGE = "/var/antctl/services"
         LOG_DIR = "/var/log/antnode"
         BOOTSTRAP_CACHE_DIR = "/var/antctl/bootstrap-cache"
     else:
-        # Linux user: Use XDG Base Directory specification
+        # User-level paths for systemd+user or setsid+user (default)
         BASE_DIR = os.path.expanduser("~/.local/share/autonomi")
         NODE_STORAGE = os.path.expanduser("~/.local/share/autonomi/node")
         LOG_DIR = os.path.expanduser("~/.local/share/autonomi/logs")
         BOOTSTRAP_CACHE_DIR = os.path.expanduser("~/.local/share/autonomi/bootstrap-cache")
 else:
-    # Windows or other platforms
+    # Windows or other platforms (user-level only)
     BASE_DIR = os.path.expanduser("~/autonomi")
     NODE_STORAGE = os.path.expanduser("~/autonomi/node")
     LOG_DIR = os.path.expanduser("~/autonomi/logs")
@@ -70,12 +190,30 @@ else:
 LOCK_FILE = os.path.join(BASE_DIR, "wnm_active")
 DEFAULT_DB_PATH = f"sqlite:///{os.path.join(BASE_DIR, 'colony.db')}"
 
-# Create directories if they don't exist (except in test mode)
+# Create minimal directories needed for config.py (except in test mode)
+# Note: NODE_STORAGE and LOG_DIR are created by ProcessManager when nodes are created
 if not os.getenv("WNM_TEST_MODE"):
-    os.makedirs(BASE_DIR, exist_ok=True)
-    os.makedirs(NODE_STORAGE, exist_ok=True)
-    os.makedirs(LOG_DIR, exist_ok=True)
-    os.makedirs(BOOTSTRAP_CACHE_DIR, exist_ok=True)
+    if _PM_MODE == "sudo":
+        # For sudo mode with system paths, use sudo to create directories
+        for directory in [BASE_DIR, BOOTSTRAP_CACHE_DIR]:
+            if not os.path.exists(directory):
+                try:
+                    subprocess.run(
+                        ["sudo", "mkdir", "-p", directory],
+                        check=True,
+                        stdout=subprocess.PIPE,
+                        stderr=subprocess.PIPE
+                    )
+                except (subprocess.CalledProcessError, FileNotFoundError) as e:
+                    # If sudo fails or isn't available, warn but continue
+                    logging.warning(
+                        f"Could not create system directory {directory}: {e}. "
+                        f"You may need to run: sudo mkdir -p {directory}"
+                    )
+    else:
+        # For user mode, create directories normally (no sudo needed)
+        os.makedirs(BASE_DIR, exist_ok=True)
+        os.makedirs(BOOTSTRAP_CACHE_DIR, exist_ok=True)
 
 
 # Config file parser
@@ -89,11 +227,13 @@ def load_config():
 
     c.add("-c", "--config", is_config_file=True, help="config file path")
     c.add("-v", help="verbose", action="store_true")
+    c.add("--version", help="Show version and exit", action="store_true")
+    c.add("--remove_lockfile", help="Remove the lock file and exit", action="store_true")
     c.add(
         "--dbpath",
         env_var="DBPATH",
         help="Path to the database",
-        default="sqlite:///colony.db",
+        default=DEFAULT_DB_PATH,
     )
     c.add("--loglevel", env_var="LOGLEVEL", help="Log level")
     c.add(
@@ -217,6 +357,12 @@ def load_config():
         type=int,
         default=1,
     )
+    c.add(
+        "--process_manager",
+        env_var="PROCESS_MANAGER",
+        help="Process manager to use: systemd+sudo, systemd+user, setsid+sudo, setsid+user, launchd+sudo, launchd+user",
+        choices=["systemd+sudo", "systemd+user", "setsid+sudo", "setsid+user", "launchd+sudo", "launchd+user"],
+    )
 
     options = c.parse_known_args()[0] or []
     # Return the first result from parse_known_args, ignore unknown options
@@ -334,10 +480,22 @@ def merge_config_changes(options, machine_config):
         cfg["environment"] = options.environment
     if options.start_args and options.start_args != machine_config.start_args:
         cfg["start_args"] = options.start_args
+    if options.process_manager and options.process_manager != machine_config.process_manager:
+        cfg["process_manager"] = options.process_manager
 
     return cfg
 
 
+# Helper function to safely get option values (handles Mock objects in tests)
+def _get_option(options, attr_name, default=None):
+    """Safely get an attribute from options, handling Mock objects in tests."""
+    value = getattr(options, attr_name, default)
+    # If it's a Mock object (has _mock_name attribute), treat as None
+    if hasattr(value, "_mock_name"):
+        return default
+    return value if value is not None else default
+
+
 # Get anm configuration
 def load_anm_config(options):
     anm_config = {}
@@ -353,29 +511,29 @@ def load_anm_config(options):
     # What can we save from /var/antctl/config
     if os.path.exists("/var/antctl/config"):
         load_dotenv("/var/antctl/config")
-    anm_config["node_cap"] = int(os.getenv("NodeCap") or options.node_cap or 20)
+    anm_config["node_cap"] = int(os.getenv("NodeCap") or _get_option(options, "node_cap") or 20)
     anm_config["cpu_less_than"] = int(
-        os.getenv("CpuLessThan") or options.cpu_less_than or 50
+        os.getenv("CpuLessThan") or _get_option(options, "cpu_less_than") or 50
     )
-    anm_config["cpu_remove"] = int(os.getenv("CpuRemove") or options.cpu_remove or 70)
+    anm_config["cpu_remove"] = int(os.getenv("CpuRemove") or _get_option(options, "cpu_remove") or 70)
     anm_config["mem_less_than"] = int(
-        os.getenv("MemLessThan") or options.mem_less_than or 70
+        os.getenv("MemLessThan") or _get_option(options, "mem_less_than") or 70
     )
-    anm_config["mem_remove"] = int(os.getenv("MemRemove") or options.mem_remove or 90)
-    anm_config["hd_less_than"] = int(os.getenv("HDLessThan") or options.hd_less_than or 70)
-    anm_config["hd_remove"] = int(os.getenv("HDRemove") or options.hd_remove or 90)
-    anm_config["delay_start"] = int(os.getenv("DelayStart") or options.delay_start or 300)
+    anm_config["mem_remove"] = int(os.getenv("MemRemove") or _get_option(options, "mem_remove") or 90)
+    anm_config["hd_less_than"] = int(os.getenv("HDLessThan") or _get_option(options, "hd_less_than") or 70)
+    anm_config["hd_remove"] = int(os.getenv("HDRemove") or _get_option(options, "hd_remove") or 90)
+    anm_config["delay_start"] = int(os.getenv("DelayStart") or _get_option(options, "delay_start") or 300)
     anm_config["delay_upgrade"] = int(
-        os.getenv("DelayUpgrade") or options.delay_upgrade or 300
+        os.getenv("DelayUpgrade") or _get_option(options, "delay_upgrade") or 300
     )
     anm_config["delay_restart"] = int(
-        os.getenv("DelayRestart") or options.delay_restart or 600
+        os.getenv("DelayRestart") or _get_option(options, "delay_restart") or 600
     )
     anm_config["delay_remove"] = int(
-        os.getenv("DelayRemove") or options.delay_remove or 300
+        os.getenv("DelayRemove") or _get_option(options, "delay_remove") or 300
     )
     anm_config["node_storage"] = (
-        os.getenv("NodeStorage") or options.node_storage or NODE_STORAGE
+        os.getenv("NodeStorage") or _get_option(options, "node_storage") or NODE_STORAGE
     )
     # Default to the faucet donation address
     try:
@@ -389,12 +547,12 @@ def load_anm_config(options):
             )[0]
         except (IndexError, TypeError) as e:
             logging.debug(f"Unable to parse RewardsAddress from env: {e}")
-            anm_config["rewards_address"] = options.rewards_address
+            anm_config["rewards_address"] = _get_option(options, "rewards_address")
             if not anm_config["rewards_address"]:
                 logging.warning("Unable to detect RewardsAddress")
                 sys.exit(1)
     anm_config["donate_address"] = (
-        os.getenv("DonateAddress") or options.donate_address or DONATE
+        os.getenv("DonateAddress") or _get_option(options, "donate_address") or DONATE
     )
     anm_config["max_load_average_allowed"] = float(
         os.getenv("MaxLoadAverageAllowed") or anm_config["cpu_count"]
@@ -409,10 +567,10 @@ def load_anm_config(options):
         anm_config["port_start"] = int(re.findall(r"ntpr\=(\d+)", data)[0])
     except (FileNotFoundError, IndexError, ValueError) as e:
         logging.debug(f"Unable to read PortStart from anms.sh: {e}")
-        anm_config["port_start"] = options.port_start or 55
+        anm_config["port_start"] = _get_option(options, "port_start") or 55
 
     anm_config["metrics_port_start"] = (
-        options.metrics_port_start or 13
+        _get_option(options, "metrics_port_start") or 13
     )  # This is hardcoded in the anm.sh script
 
     anm_config["hdio_read_less_than"] = int(os.getenv("HDIOReadLessThan") or 0)
@@ -425,10 +583,20 @@ def load_anm_config(options):
     anm_config["netio_write_remove"] = int(os.getenv("NetIOWriteRemove") or 0)
     # Timer for last stopped nodes
     anm_config["last_stopped_at"] = 0
-    anm_config["host"] = os.getenv("Host") or options.host or "127.0.0.1"
-    anm_config["crisis_bytes"] = options.host or DEFAULT_CRISIS_BYTES
-    anm_config["environment"] = options.environment or ""
-    anm_config["start_args"] = options.start_args or ""
+    anm_config["host"] = os.getenv("Host") or _get_option(options, "host") or "127.0.0.1"
+    anm_config["crisis_bytes"] = _get_option(options, "crisis_bytes") or DEFAULT_CRISIS_BYTES
+    anm_config["environment"] = _get_option(options, "environment") or ""
+    anm_config["start_args"] = _get_option(options, "start_args") or ""
+
+    # Set default process manager based on platform if not specified
+    if _get_option(options, "process_manager"):
+        anm_config["process_manager"] = _get_option(options, "process_manager")
+    elif PLATFORM == "Darwin":
+        anm_config["process_manager"] = "launchd+user"
+    elif PLATFORM == "Linux":
+        anm_config["process_manager"] = "systemd+user"
+    else:
+        anm_config["process_manager"] = "systemd+user"
 
     return anm_config
 
@@ -492,64 +660,48 @@ def define_machine(options):
     machine = {
         "id": 1,
         "cpu_count": cpucount,
-        "node_cap": int(options.node_cap) if options.node_cap else 20,
-        "cpu_less_than": int(options.cpu_less_than) if options.cpu_less_than else 50,
-        "cpu_remove": int(options.cpu_remove) if options.cpu_remove else 70,
-        "mem_less_than": int(options.mem_less_than) if options.mem_less_than else 70,
-        "mem_remove": int(options.mem_remove) if options.mem_remove else 90,
-        "hd_less_than": int(options.hd_less_than) if options.hd_less_than else 70,
-        "hd_remove": int(options.hd_remove) if options.hd_remove else 90,
-        "delay_start": int(options.delay_start) if options.delay_start else 300,
-        "delay_upgrade": int(options.delay_upgrade) if options.delay_upgrade else 300,
-        "delay_remove": int(options.delay_remove) if options.delay_remove else 300,
-        "node_storage": options.node_storage or NODE_STORAGE,
-        "rewards_address": options.rewards_address,
-        "donate_address": options.donate_address
-        or "0x00455d78f850b0358E8cea5be24d415E01E107CF",
-        "max_load_average_allowed": (
-            float(options.max_load_average_allowed)
-            if options.max_load_average_allowed
-            else cpucount
-        ),
-        "desired_load_average": (
-            float(options.desired_load_average)
-            if options.desired_load_average
-            else cpucount * 0.6
-        ),
-        "port_start": int(options.port_start) if options.port_start else 55,
-        "hdio_read_less_than": (
-            int(options.hdio_read_less_than) if options.hdio_read_less_than else 0
-        ),
-        "hdio_read_remove": int(options.hdio_read_remove) if options.hdio_read_remove else 0,
-        "hdio_write_less_than": (
-            int(options.hdio_write_less_than) if options.hdio_write_less_than else 0
-        ),
-        "hdio_write_remove": (
-            int(options.hdio_write_remove) if options.hdio_write_remove else 0
-        ),
-        "netio_read_less_than": (
-            int(options.netio_read_less_than) if options.netio_read_less_than else 0
-        ),
-        "netio_read_remove": (
-            int(options.netio_read_remove) if options.netio_read_remove else 0
-        ),
-        "netio_write_less_than": (
-            int(options.netio_write_less_than) if options.netio_write_less_than else 0
-        ),
-        "netio_write_remove": (
-            int(options.netio_write_remove) if options.netio_write_remove else 0
-        ),
+        "node_cap": int(_get_option(options, "node_cap") or 20),
+        "cpu_less_than": int(_get_option(options, "cpu_less_than") or 50),
+        "cpu_remove": int(_get_option(options, "cpu_remove") or 70),
+        "mem_less_than": int(_get_option(options, "mem_less_than") or 70),
+        "mem_remove": int(_get_option(options, "mem_remove") or 90),
+        "hd_less_than": int(_get_option(options, "hd_less_than") or 70),
+        "hd_remove": int(_get_option(options, "hd_remove") or 90),
+        "delay_start": int(_get_option(options, "delay_start") or 300),
+        "delay_upgrade": int(_get_option(options, "delay_upgrade") or 300),
+        "delay_remove": int(_get_option(options, "delay_remove") or 300),
+        "node_storage": _get_option(options, "node_storage") or NODE_STORAGE,
+        "rewards_address": _get_option(options, "rewards_address"),
+        "donate_address": _get_option(options, "donate_address") or FAUCET,
+        "max_load_average_allowed": float(_get_option(options, "max_load_average_allowed") or cpucount),
+        "desired_load_average": float(_get_option(options, "desired_load_average") or cpucount * 0.6),
+        "port_start": int(_get_option(options, "port_start") or 55),
+        "hdio_read_less_than": int(_get_option(options, "hdio_read_less_than") or 0),
+        "hdio_read_remove": int(_get_option(options, "hdio_read_remove") or 0),
+        "hdio_write_less_than": int(_get_option(options, "hdio_write_less_than") or 0),
+        "hdio_write_remove": int(_get_option(options, "hdio_write_remove") or 0),
+        "netio_read_less_than": int(_get_option(options, "netio_read_less_than") or 0),
+        "netio_read_remove": int(_get_option(options, "netio_read_remove") or 0),
+        "netio_write_less_than": int(_get_option(options, "netio_write_less_than") or 0),
+        "netio_write_remove": int(_get_option(options, "netio_write_remove") or 0),
         "last_stopped_at": 0,
-        "host": options.host or "127.0.0.1",
-        "crisis_bytes": (
-            int(options.crisis_bytes) if options.crisis_bytes else DEFAULT_CRISIS_BYTES
-        ),
-        "metrics_port_start": (
-            int(options.metrics_port_start) if options.metrics_port_start else 13
-        ),
-        "environment": options.environment if options.environment else "",
-        "start_args": options.start_args if options.start_args else "",
+        "host": _get_option(options, "host") or "127.0.0.1",
+        "crisis_bytes": int(_get_option(options, "crisis_bytes") or DEFAULT_CRISIS_BYTES),
+        "metrics_port_start": int(_get_option(options, "metrics_port_start") or 13),
+        "environment": _get_option(options, "environment") or "",
+        "start_args": _get_option(options, "start_args") or "",
     }
+
+    # Set default process manager based on platform if not specified
+    if _get_option(options, "process_manager"):
+        machine["process_manager"] = _get_option(options, "process_manager")
+    elif PLATFORM == "Darwin":
+        machine["process_manager"] = "launchd+user"
+    elif PLATFORM == "Linux":
+        machine["process_manager"] = "systemd+user"
+    else:
+        machine["process_manager"] = "systemd+user"
+
     with S() as session:
         session.execute(insert(Machine), [machine])
         session.commit()
@@ -572,30 +724,43 @@ def apply_config_updates(config_updates):
 # Load options now so we know what database to load
 options = load_config()
 
-# Setup Database engine
-engine = create_engine(options.dbpath, echo=True)
+# Skip database initialization for --version and --remove_lockfile
+# These flags should work without any database or lock file checks
+_SKIP_DB_INIT = getattr(options, 'version', False) or getattr(options, 'remove_lockfile', False)
 
-# Generate ORM
-Base.metadata.create_all(engine)
-
-# Create a connection to the ORM
-session_factory = sessionmaker(bind=engine)
-S = scoped_session(session_factory)
+# Setup Database engine (skip if --version or --remove_lockfile)
+if not _SKIP_DB_INIT:
+    engine = create_engine(options.dbpath, echo=True)
+    # Generate ORM
+    Base.metadata.create_all(engine)
+    # Create a connection to the ORM
+    session_factory = sessionmaker(bind=engine)
+    S = scoped_session(session_factory)
+else:
+    # Create dummy objects for --version and --remove_lockfile
+    engine = None
+    S = None
 
 # Remember if we init a new machine
 did_we_init = False
 
-# Skip machine configuration check in test mode
-if os.getenv("WNM_TEST_MODE"):
-    # In test mode, use a minimal machine config or None
+# Skip machine configuration check in test mode or when using --version/--remove_lockfile
+if os.getenv("WNM_TEST_MODE") or _SKIP_DB_INIT:
+    # In test mode or with --version/--remove_lockfile, use a minimal machine config or None
     machine_config = None
 else:
     # Check if we have a defined machine
-    with S() as session:
-        machine_config = session.execute(select(Machine)).first()
+    try:
+        with S() as session:
+            machine_config = session.execute(select(Machine)).first()
+    except Exception as e:
+        # If there's an error loading the machine config (e.g., schema mismatch),
+        # set to None and let the init process handle it
+        logging.debug(f"Error loading machine config (may need schema upgrade): {e}")
+        machine_config = None
 
 # No machine configured
-if not machine_config and not os.getenv("WNM_TEST_MODE"):
+if not machine_config and not os.getenv("WNM_TEST_MODE") and not _SKIP_DB_INIT:
     # Are we initializing a new machine?
     if options.init:
         # Init and dry-run are mutually exclusive
@@ -654,12 +819,12 @@ else:
         else:
             logging.warning("Please confirm the teardown with --confirm")
             sys.exit(1)
-    # Get Machine from Row (skip in test mode)
-    if not os.getenv("WNM_TEST_MODE"):
+    # Get Machine from Row (skip in test mode or when using --version/--remove_lockfile)
+    if not os.getenv("WNM_TEST_MODE") and not _SKIP_DB_INIT:
         machine_config = machine_config[0]
 
-# Collect the proposed changes unless we are initializing (skip in test mode)
-config_updates = merge_config_changes(options, machine_config) if not os.getenv("WNM_TEST_MODE") else {}
+# Collect the proposed changes unless we are initializing (skip in test mode or when using --version/--remove_lockfile)
+config_updates = merge_config_changes(options, machine_config) if not os.getenv("WNM_TEST_MODE") and not _SKIP_DB_INIT else {}
 # Failfirst on invalid config change
 if (
     "port_start" in config_updates or "metrics_port_start" in config_updates
